==> cscec5b-fbxt-impl-3.0.1-20240418.090243-189-sources.jar: com/ejianc/business/fbxt/odd/bean/OddSetEntity.java <==
package com.ejianc.business.fbxt.odd.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包协同设置实体
 *
 * @author generator
 *
 */
 @TableName("ejc_fbxt_odd_set")
public class OddSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_parent_id")
    private Long orgParentId; // 上级组织主键
    @TableField(value="set_state")
    private Boolean setState; // 是否设置，0-未设置，1-已设置
    @TableField(value="supp_status")
    private Boolean suppStatus; // 是否启用供方协同，0-未启用，1-已启用
    @TableField(value="confirm_status")
    private Boolean confirmStatus; // 是否供方确认，0-不需确认，1-需确认
    @TableField(value="force_apply")
    private Boolean forceApply;    // 是否强制申请单，0-不强制，1-强制
    @TableField(value="supp_assbook_excess")
    private Boolean suppAssbookExcess; // 是否允许供应商超量发起施工任务书，0-未启用，1-已启用
    @TableField(value="supp_odd_add")
    private Boolean suppOddAdd; // 是否允许供应商自制发起用工单，0-未启用，1-已启用

    @TableField(exist=false)
    @SubEntity(serviceName="receiveService",pidName = "setId")
    private List<ReceiveEntity> receiveLists = new ArrayList<>(); // 接收人


    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织主键
     */
    public Long getOrgParentId() {
        return orgParentId;
    }

    /**
     * 上级组织主键
     */
    public void setOrgParentId(Long orgParentId) {
        this.orgParentId = orgParentId;
    }
    /**
     * 是否设置，0-未设置，1-已设置
     */
    public Boolean getSetState() {
        return setState;
    }

    /**
     * 是否设置，0-未设置，1-已设置
     */
    public void setSetState(Boolean setState) {
        this.setState = setState;
    }
    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public Boolean getSuppStatus() {
        return suppStatus;
    }

    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public void setSuppStatus(Boolean suppStatus) {
        this.suppStatus = suppStatus;
    }
    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public Boolean getConfirmStatus() {
        return confirmStatus;
    }

    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public void setConfirmStatus(Boolean confirmStatus) {
        this.confirmStatus = confirmStatus;
    }

    public Boolean getForceApply() {
        return forceApply;
    }

    public void setForceApply(Boolean forceApply) {
        this.forceApply = forceApply;
    }

    public Boolean getSuppAssbookExcess() {
        return suppAssbookExcess;
    }

    public void setSuppAssbookExcess(Boolean suppAssbookExcess) {
        this.suppAssbookExcess = suppAssbookExcess;
    }

    public Boolean getSuppOddAdd() {
        return suppOddAdd;
    }

    public void setSuppOddAdd(Boolean suppOddAdd) {
        this.suppOddAdd = suppOddAdd;
    }

    public List<ReceiveEntity> getReceiveLists() {
        return receiveLists;
    }

    public void setReceiveLists(List<ReceiveEntity> receiveLists) {
        this.receiveLists = receiveLists;
    }
}

==> cscec5b-fbxt-impl-3.0.1-20251014.091841-203-sources.jar: com/ejianc/business/fbxt/odd/bean/OddSetEntity.java <==
package com.ejianc.business.fbxt.odd.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包协同设置实体
 *
 * @author generator
 *
 */
 @TableName("ejc_fbxt_odd_set")
public class OddSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_parent_id")
    private Long orgParentId; // 上级组织主键
    @TableField(value="set_state")
    private Boolean setState; // 是否设置，0-未设置，1-已设置
    @TableField(value="supp_status")
    private Boolean suppStatus; // 是否启用供方协同，0-未启用，1-已启用
    @TableField(value="confirm_status")
    private Boolean confirmStatus; // 是否供方确认，0-不需确认，1-需确认
    @TableField(value="force_apply")
    private Boolean forceApply;    // 是否强制申请单，0-不强制，1-强制
    @TableField(value="supp_assbook_excess")
    private Boolean suppAssbookExcess; // 是否允许供应商超量发起施工任务书，0-未启用，1-已启用
    @TableField(value="supp_odd_add")
    private Boolean suppOddAdd; // 是否允许供应商自制发起用工单，0-未启用，1-已启用
    @TableField(value="set_construction_assignment")
    private Boolean setConstructionAssignment; // 是否供应商需要确认后发起施工任务书，0-未启用，1-已启用

    @TableField(exist=false)
    @SubEntity(serviceName="receiveService",pidName = "setId")
    private List<ReceiveEntity> receiveLists = new ArrayList<>(); // 接收人


    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织主键
     */
    public Long getOrgParentId() {
        return orgParentId;
    }

    /**
     * 上级组织主键
     */
    public void setOrgParentId(Long orgParentId) {
        this.orgParentId = orgParentId;
    }
    /**
     * 是否设置，0-未设置，1-已设置
     */
    public Boolean getSetState() {
        return setState;
    }

    /**
     * 是否设置，0-未设置，1-已设置
     */
    public void setSetState(Boolean setState) {
        this.setState = setState;
    }
    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public Boolean getSuppStatus() {
        return suppStatus;
    }

    /**
     * 是否启用供方协同，0-未启用，1-已启用
     */
    public void setSuppStatus(Boolean suppStatus) {
        this.suppStatus = suppStatus;
    }
    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public Boolean getConfirmStatus() {
        return confirmStatus;
    }

    /**
     * 是否供方确认，0-不需确认，1-需确认
     */
    public void setConfirmStatus(Boolean confirmStatus) {
        this.confirmStatus = confirmStatus;
    }

    public Boolean getForceApply() {
        return forceApply;
    }

    public void setForceApply(Boolean forceApply) {
        this.forceApply = forceApply;
    }

    public Boolean getSuppAssbookExcess() {
        return suppAssbookExcess;
    }

    public void setSuppAssbookExcess(Boolean suppAssbookExcess) {
        this.suppAssbookExcess = suppAssbookExcess;
    }

    public Boolean getSuppOddAdd() {
        return suppOddAdd;
    }

    public void setSuppOddAdd(Boolean suppOddAdd) {
        this.suppOddAdd = suppOddAdd;
    }

    public List<ReceiveEntity> getReceiveLists() {
        return receiveLists;
    }

    public void setReceiveLists(List<ReceiveEntity> receiveLists) {
        this.receiveLists = receiveLists;
    }

    public Boolean getSetConstructionAssignment() {
        return setConstructionAssignment;
    }

    public void setSetConstructionAssignment(Boolean setConstructionAssignment) {
        this.setConstructionAssignment = setConstructionAssignment;
    }
}
